@@ -249,6 +249,25 @@ def reconciled(product):
 
         message = str(dataset_reconcile)
         subject = "[blueline] Reconcile FUP"
+
+        print("=================== FUP SUCCESS ===========================")
+        print(fup_success_name)
+        print()
+
+        print("=================== FUP ERROR ===========================")
+        print(fup_error_name)
+        print()
+
+        print("=================== REPORT ===========================")
+        print("fup-ed in Aiguiller: {}".format(len(customers_aiguiller)))
+        print(
+            "fup-ed customer in Aiguiller also in SI: {}"
+            .format(len(common_customers))
+        )
+        print("fup-ed both in Aiguiller and SI: {}".format(
+            len(fup_success_name)))
+        print("fup-ed in Aiguiller and NOT in SI: {}".format(
+            len(fup_error_name)))
     else:
         bool_error = False
         dataset_reconcile = tablib.Dataset()
